@@ -93,9 +93,15 @@ def set_dataframe_columntypes(df):
     if 'DaysSinceFirstContact' in df:
         df['DaysSinceFirstContact'] = df['DaysSinceFirstContact'].astype(
             'float16')
+    if 'Growth3M' in df:
+        df['Growth3M'] = df['Growth3M'].astype('float32')
+    if 'Growth6M' in df:
+        df['Growth6M'] = df['Growth6M'].astype('float32')
+    if 'Growth12M' in df:
+        df['Growth12M'] = df['Growth12M'].astype('float32')
     if 'DaysSincePositionStart' in df:
-        df['DaysSincePositionStart'] = df['DaysSincePositionStart'].astype(
-            'float16')
+        df['DaysSincePositionStart'] = df['DaysSincePositionStart'].astype('float16')
+
 
     logger.info("Datatypes after modification")
     logger.info(f'{df.dtypes}')
